@@ -4,8 +4,13 @@ from datalabs.tasks import (
     cloze,
     conditional_generation,
     coreference_resolution,
+    dialogue,
+    event_extraction,
+    grammatical_error_correction,
     kg_prediction,
     machine_translation,
+    multilabel_classification,
+    poetry,
     question_answering,
     retrieval,
     semantic_parsing,
@@ -29,6 +34,9 @@ from datalabs.utils.logging import get_logger
 __all__ = [
     "conditional_generation",
     "coreference_resolution",
+    "dialogue",
+    "event_extraction",
+    "grammatical_error_correction",
     "kg_prediction",
     "machine_translation",
     "question_answering",
@@ -39,12 +47,14 @@ __all__ = [
     "span_text_classification",
     "summarization",
     "text_classification",
+    "multilabel_classification",
     "text_pair_classification",
     "cloze",
     "text_editing",
     "TaskTemplate",
     "TaskType",
     "get_task",
+    "poetry",
     "register_task",
     "TASK_REGISTRY",
     "get_logger",
